from flask_login import current_user
from functools import wraps
from app.models import Permission as UserPermission


def login_required(f):
    @wraps(f)
    def wrapper(*args, **kwargs):
        if current_user.is_authenticated:
            return f(*args, **kwargs)
        return {'code': 401, 'body': 'Unauthorized'}
    return wrapper


def permission_required(permission):
    def decorator(f):
        @wraps(f)
        def wrapper(*args, **kwargs):
            if not current_user.can(permission):
                return {'code': 403, 'body': 'Forbidden'}
            return f(*args, **kwargs)
        return wrapper
    return decorator


def admin_required(f):
    return permission_required(UserPermission.ADMINISTRATE)(f)
